//
//  ScrollableStackView.swift
//  AlphaWallet
//
//  Created by Vladyslav Shepitko on 02.03.2021.
//

import UIKit

struct ScrollableStackViewModel {
    var backgroundColor: UIColor = .clear
}

class ScrollableStackView: UIView {

    lazy var stackView: UIStackView = {
        let stackView = UIStackView()
        stackView.axis = .vertical
        stackView.spacing = 0
        stackView.translatesAutoresizingMaskIntoConstraints = false

        return stackView
    }()

    lazy var scrollView: UIScrollView = {
        let scrollView = UIScrollView()
        scrollView.translatesAutoresizingMaskIntoConstraints = false
        scrollView.addSubview(stackView)
        return scrollView
    }()

    init(viewModel: ScrollableStackViewModel = .init()) {
        super.init(frame: .zero)
        translatesAutoresizingMaskIntoConstraints = false

        addSubview(scrollView)

        NSLayoutConstraint.activate([
            stackView.leadingAnchor.constraint(equalTo: leadingAnchor),
            stackView.trailingAnchor.constraint(equalTo: trailingAnchor),
            stackView.topAnchor.constraint(equalTo: scrollView.topAnchor),
            stackView.bottomAnchor.constraint(equalTo: scrollView.bottomAnchor),
        ] + scrollView.anchorsConstraint(to: self))

        configure(viewModel: viewModel)
    }

    required init?(coder: NSCoder) {
        return nil
    }

    private func configure(viewModel: ScrollableStackViewModel) {
        backgroundColor = viewModel.backgroundColor
        scrollView.backgroundColor = viewModel.backgroundColor
    }
}
